@@ -27,7 +27,9 @@ def connection_data():
 def test_load_test_server_yaml(load_test_server_yaml, connection_data):
     server = connection_data()
     with tempfile.NamedTemporaryFile(mode="w") as fp:
-        ruamel.yaml.dump(server, fp, ruamel.yaml.SafeDumper)
+        yaml = ruamel.yaml.YAML(typ="rt", pure=True)
+        yaml.indent = 4
+        yaml.dump(server, fp)
         fp.flush()
         config = load_test_server_yaml(fp.name)
         assert server == {
@@ -44,5 +46,6 @@ def test_save_test_server_yaml(save_test_server_yaml, connection_data):
         save_test_server_yaml(**server, path=fp.name)
         fp.flush()
         fp.seek(0)
-        config = ruamel.yaml.load(fp, ruamel.yaml.Loader)
+        yaml = ruamel.yaml.YAML(typ="rt", pure=True)
+        config = yaml.load(fp)
         assert config == server
